import { json, 
        select,
        tree,
        hierarchy,
        linkVertical
       } from 'd3';

const svg = select('svg');

const width = document.body.clientWidth;
const height = document.body.clientHeight;
const margin = {top: 20, bottom: 200, right: 50, left: 100};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = tree()
    .size([innerHeight, innerWidth- 200]);

const g = svg
    .attr('width', width)
    .attr('height', height)
    .append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`);
  

json('data.json')
  .then(data => {
  const root = hierarchy(data);
  const links = treeLayout(root).links();
  const linkPathGenerator = linkVertical()
    .x(d => d.x)
    .y(d => d.y);
  
  console.log(links);
  
  g.selectAll('path').data(links)
     .enter().append('path')
     .attr('d', linkPathGenerator);
  
  g.selectAll('text').data(root.descendants())
     .enter().append('text')
     .attr('x', d => d.x)
     .attr('y', d => d.y)
     .attr('text-anchor', 'middle')
     .attr('class', d => d.children? 'parents': 'special')
     .text(d => d.data.data.id)
});

